@@ -89,6 +89,14 @@ state_lookup <- function(state) {
   st$fips[matched]
 }
 
+all_state_fips <- c("01", "02", "04", "05", "06",
+                    "08", "09", "10", "11", "12", "13", "15", "16", "17", "18",
+                    "19", "20", "21", "22", "23", "24", "25", "26", "27",
+                    "28", "29", "30", "31", "32", "33", "34", "35", "36", "37",
+                    "38", "39", "40", "41", "42", "44", "45", "46", "47",
+                    "48", "49", "50", "51", "53", "54", "55", "56", "60", "66",
+                    "69", "72", "74", "78")
+
 county_lookup <- function(state, counties) {
   st <- get("county_fips_2020")
   st <- st[st$state %in% state, ]
